==> haskell-http-date-0.0.11-199-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-date
version:              0.0.11
visibility:           public
id:                   http-date-0.0.11-9tgeJtJstSL81Gt2T60w1P
key:                  http-date-0.0.11-9tgeJtJstSL81Gt2T60w1P
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  94bbc8822c5814f2b985b1f04fb2d69b
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-date-0.0.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-date-0.0.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-date-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-date
hs-libraries:         HShttp-date-0.0.11-9tgeJtJstSL81Gt2T60w1P
depends:
    array-0.5.4.0 attoparsec-0.14.4-4kZjCdGgUdQ9XykEL1OaXf
    base-4.17.2.1 bytestring-0.11.5.3 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-date-0.0.11-200-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-date.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-date
version:              0.0.11
visibility:           public
id:                   http-date-0.0.11-1ghT58rXLGYBkwumzRsQHQ
key:                  http-date-0.0.11-1ghT58rXLGYBkwumzRsQHQ
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             HTTP Date parser/formatter
description:          Fast parser and formatter for HTTP Date
category:             Network, Web
abi:                  58538dce63b85d74468781f32e18ce55
exposed:              True
exposed-modules:      Network.HTTP.Date
hidden-modules:
    Network.HTTP.Date.Converter Network.HTTP.Date.Formatter
    Network.HTTP.Date.Types Network.HTTP.Date.Parser

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-date-0.0.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-date-0.0.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-date-0.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-date
hs-libraries:         HShttp-date-0.0.11-1ghT58rXLGYBkwumzRsQHQ
depends:
    array-0.5.4.0 attoparsec-0.14.4-JY3WRVtwl2HEigkrgC0fwc
    base-4.17.2.1 bytestring-0.11.5.3 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-http-date/html/http-date.haddock
haddock-html:         /usr/share/doc/haskell-http-date/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
